import { Component, Inject, OnInit } from '@angular/core';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material';

// Form imports
import {
  FormBuilder,
  FormGroup,
  FormControl,
  Validators,
} from '@angular/forms';

@Component({
  selector: 'cse-prompt-dialog',
  templateUrl: './prompt-dialog.component.html',
  styleUrls: ['../dialogs.scss'],
})
export class PromptDialogComponent implements OnInit {
  title: string;
  text: string[];
  inputName: string;
  placeholder?: string;
  tooltip?: string;
  cancelText: string;
  confirmText: string;
  confirmColor: string;

  inputForm: FormGroup;
  initalValue: string;

  constructor(
    private dialogRef: MatDialogRef<PromptDialogComponent>,
    private fb: FormBuilder,
    @Inject(MAT_DIALOG_DATA) data: any,
  ) {
    const {
      title = 'User Input Required',
      text = [],
      inputName = 'Data',
      initalValue = '',
      placeholder,
      tooltip,
      cancelText = 'Cancel',
      confirmText = 'Confirm',
      confirmColor = 'primary',
    } = data;

    this.title = title;
    this.text = text;
    this.inputName = inputName;
    this.placeholder = placeholder;
    this.tooltip = tooltip;
    this.cancelText = cancelText;
    this.confirmText = confirmText;
    this.confirmColor = confirmColor;
    this.initalValue = initalValue;

    if (typeof text === 'string') {
      this.text = [text];
    }
  }

  ngOnInit() {
    // Deafults for input form
    this.inputForm = this.fb.group({
      value: this.initalValue,
    });
  }

  confirm() {
    const { value } = this.inputForm.value;
    this.dialogRef.close({ confirmed: true, value });
  }

  cancel() {
    const { value } = this.inputForm.value;
    this.dialogRef.close({ confirmed: false, value });
  }
}
